//----------------------------------------------------------------------------
//                                                                          --
//                         Module Declaration                               --
//                                                                          --
//----------------------------------------------------------------------------
module RGB_MultiColors 
(
    // outputs
    output  wire        REDn,       // Red
    output  wire        BLUn,       // Blue
    output  wire        GRNn        // Green
);
    reg         rstn;
    reg [27:0]  frequency_counter_i;

//=============Internal Constants======================

    parameter SIZE = 3 ;
    parameter RED  = 3'b001, BLUE = 3'b010, GREEN = 3'b100, MAGENTA = 3'b011, YELLOW = 3'b101, CYAN = 3'b110, WHITE = 3'b111 ;

//=============Internal Variables======================

    reg   [SIZE-1:0]          state ;

//----------------------------------------------------------------------------
//                                                                          --
//                       Internal Oscillator                                --
//                                                                          --
//----------------------------------------------------------------------------
    SB_HFOSC  u_SB_HFOSC(.CLKHFPU(1), .CLKHFEN(1), .CLKHF(int_osc));


//----------------------------------------------------------------------------
//                                                                          --
//                       Counter                                            --
//                                                                          --
//----------------------------------------------------------------------------
    always @(posedge int_osc) begin
	    frequency_counter_i <= frequency_counter_i + 1'b1;
    end

//----------------------------------------------------------------------------
//                                                                          --
//                       Color State Machine                                --
//                                                                          --
//----------------------------------------------------------------------------

always @ (posedge frequency_counter_i[24])
 begin : FSM
// if (rstn == 1'b0) begin
//   state <=  #1  RED;
// end else
  case(state)
    RED : 
          state <=  #1  BLUE;
    BLUE : 
          state <=  #1  GREEN;
    GREEN : 
          state <=  #1  MAGENTA;
    MAGENTA : 
          state <=  #1  CYAN;
    CYAN : 
          state <=  #1  YELLOW;
    YELLOW : 
          state <=  #1  WHITE;
    WHITE : 
          state <=  #1  RED;
    default : state <=  #1  RED;
  endcase
end

//----------------------------------------------------------------------------
//                                                                          --
//                       Instantiate RGB primitive                          --
//                                                                          --
//----------------------------------------------------------------------------
    SB_RGBA_DRV RGB_DRIVER ( 
      .RGBLEDEN (1'b1),
      .RGB0PWM  (state[2]),
      .RGB1PWM  (state[1]),
      .RGB2PWM  (state[0]),
      .CURREN   (1'b1), 
      .RGB0     (REDn),		//Actual Hardware connection
      .RGB1     (GRNn),
      .RGB2     (BLUn)
    );
    defparam RGB_DRIVER.RGB0_CURRENT = "0b000001";
    defparam RGB_DRIVER.RGB1_CURRENT = "0b000001";
    defparam RGB_DRIVER.RGB2_CURRENT = "0b000001";

endmodule